summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorAdam J. Stewart <ajstewart426@gmail.com>2016-07-05 11:33:29 -0500
committerAdam J. Stewart <ajstewart426@gmail.com>2016-07-18 07:45:28 -0500
commit262ab401884a8b46992872b8c010fa844cb14271 (patch)
treeb6ba2dde729040d5537ac38ff2d5facd96f65d52 /lib
parent199a8af7cc4e75e66cf53c3a2bb4c9b28aec64f1 (diff)
downloadspack-262ab401884a8b46992872b8c010fa844cb14271.tar.gz
spack-262ab401884a8b46992872b8c010fa844cb14271.tar.bz2
spack-262ab401884a8b46992872b8c010fa844cb14271.tar.xz
spack-262ab401884a8b46992872b8c010fa844cb14271.zip
Update build_system_guess test with new class name
Diffstat (limited to 'lib')
-rw-r--r--lib/spack/spack/test/__init__.py2
-rw-r--r--lib/spack/spack/test/build_system_guess.py (renamed from lib/spack/spack/test/configure_guess.py)26
2 files changed, 17 insertions, 11 deletions
diff --git a/lib/spack/spack/test/__init__.py b/lib/spack/spack/test/__init__.py
index fb91f24721..19bc1d89d3 100644
--- a/lib/spack/spack/test/__init__.py
+++ b/lib/spack/spack/test/__init__.py
@@ -38,7 +38,7 @@ test_names = ['architecture', 'versions', 'url_parse', 'url_substitution', 'pack
'directory_layout', 'pattern', 'python_version', 'git_fetch',
'svn_fetch', 'hg_fetch', 'mirror', 'modules', 'url_extrapolate',
'cc', 'link_tree', 'spec_yaml', 'optional_deps',
- 'make_executable', 'configure_guess', 'lock', 'database',
+ 'make_executable', 'build_system_guess', 'lock', 'database',
'namespace_trie', 'yaml', 'sbang', 'environment', 'cmd.find',
'cmd.uninstall', 'cmd.test_install', 'cmd.test_compiler_cmd']
diff --git a/lib/spack/spack/test/configure_guess.py b/lib/spack/spack/test/build_system_guess.py
index bad3673e7a..80b867a528 100644
--- a/lib/spack/spack/test/configure_guess.py
+++ b/lib/spack/spack/test/build_system_guess.py
@@ -28,14 +28,14 @@ import tempfile
import unittest
from llnl.util.filesystem import *
-from spack.cmd.create import ConfigureGuesser
+from spack.cmd.create import BuildSystemGuesser
from spack.stage import Stage
from spack.test.mock_packages_test import *
from spack.util.executable import which
class InstallTest(unittest.TestCase):
"""Tests the configure guesser in spack create"""
def setUp(self):
self.tar = which('tar')
@@ -60,15 +60,11 @@ class InstallTest(unittest.TestCase):
with Stage(url) as stage:
stage.fetch()
- guesser = ConfigureGuesser()
- guesser(stage)
+ guesser = BuildSystemGuesser()
+ guesser(stage, url)
self.assertEqual(system, guesser.build_system)
- def test_python(self):
- self.check_archive('setup.py', 'python')
-
-
def test_autotools(self):
self.check_archive('configure', 'autotools')
@@ -77,7 +73,17 @@ class InstallTest(unittest.TestCase):
self.check_archive('CMakeLists.txt', 'cmake')
- def test_unknown(self):
- self.check_archive('foobar', 'unknown')
+ def test_scons(self):
+ self.check_archive('SConstruct', 'scons')
+
+ def test_python(self):
+ self.check_archive('setup.py', 'python')
+
+
+ def test_R(self):
+ self.check_archive('NAMESPACE', 'R')
+
+ def test_unknown(self):
+ self.check_archive('foobar', 'unknown')
@@ -28,14 +28,14 @@ import tempfile
from spack.util.executable import which
class InstallTest(unittest.TestCase):
- """Tests the configure guesser in spack create"""
+ """Tests the build system guesser in spack create"""
def setUp(self):
self.tar = which('tar')